@@ -786,7 +786,7 @@ final class WP_Customize_Nav_Menus {
 	 * @return WP_Post|WP_Error Inserted auto-draft post object or error.
 	 */
 	public function insert_auto_draft_post( $postarr ) {
-		if ( ! isset( $postarr['post_type'] ) || ! post_type_exists( $postarr['post_type'] )  ) {
+		if ( ! isset( $postarr['post_type'] ) ) {
 			return new WP_Error( 'unknown_post_type', __( 'Unknown post type' ) );
 		}
 		if ( empty( $postarr['post_title'] ) ) {
@@ -1327,7 +1327,6 @@ final class WP_Customize_Nav_Menus {
 	 */
 	public function customize_preview_enqueue_deps() {
 		wp_enqueue_script( 'customize-preview-nav-menus' ); // Note that we have overridden this.
-		wp_enqueue_style( 'customize-preview' );
 	}
 
 	/**
