@@ -321,15 +321,21 @@ function wp_mail( $to, $subject, $message, $headers = '', $attachments = array()
 	 * https://core.trac.wordpress.org/ticket/5007.
 	 */
 
-	if ( !isset( $from_email ) ) {
-		// Get the site domain and get rid of www.
-		$sitename = strtolower( $_SERVER['SERVER_NAME'] );
-		if ( substr( $sitename, 0, 4 ) == 'www.' ) {
-			$sitename = substr( $sitename, 4 );
-		}
-
-		$from_email = 'wordpress@' . $sitename;
-	}
+    // Thanks simlevesque @ https://news.ycombinator.com/item?id=14265092
+    if ( !isset( $from_email ) ) {
+        // Get the site domain and get rid of www.
+        $sitename = strtolower( WP_HOME );
+        if ( substr( $sitename, 0, 7 ) == 'http://' ) {
+            $sitename = substr( $sitename, 7 );
+        }
+        if ( substr( $sitename, 0, 8 ) == 'https://' ) {
+            $sitename = substr( $sitename, 8 );
+        }
+        if ( substr( $sitename, 0, 4 ) == 'www.' ) {
+            $sitename = substr( $sitename, 4 );
+        }
+        $from_email = 'wordpress@' . $sitename;
+    }
 
 	/**
 	 * Filters the email address to send from.
